@@ -134,9 +134,11 @@ class AbstractGroup:
                 data['pageid'] = 'Unknown'
             if data['pageid'] == '':
                 data['pageid'] = 'Unknown'
+            data['pageid'] = _escape(data['pageid'])
             data['escaped_url'] = _escape(data['url'])
             data['errors'] = data['errors'].split(',')
             data['errors'].sort()
+            data['url'] = data['url'].encode('utf8')
         return res
 
     @Lazy
@@ -155,7 +157,8 @@ class AbstractGroup:
 
     def renderTXT(self, fp):
         """Render this group in plain text."""
-        fp.write('%4d %s: %s\n' % (self.count, self.etype, self.evalue))
+        fp.write('%4d %s: %s\n' % (
+            self.count, self.etype.encode('utf8'), self.evalue.encode('utf8')))
         if self.bug:
             fp.write('    Bug: https://launchpad.net/bugs/%s\n' % self.bug)
         http_methods = self.formatted_http_method_count()
@@ -457,7 +460,8 @@ class AbstractTopValueSection(AbstractSection):
             fp.write('<td>%s</td>\n<td><a href="%s">%s</a></td>'
                      '\n<td>%s</td>\n' % (
                         self.field_format % value,
-                        get_absolute_url(oopsids[0]), oopsids[0], pageid))
+                        get_absolute_url(oopsids[0]), oopsids[0].encode('utf8'),
+                        _escape(pageid)))
             fp.write('</tr>\n')
         fp.write('</table>')
         fp.write('</div>')
@@ -466,7 +470,8 @@ class AbstractTopValueSection(AbstractSection):
         fp.write('=== Top %d %s ===\n\n' % (self.max_count, self.title))
         for value, oopsids, pageid in self.top_errors:
             formatted_value = self.field_format % value
-            fp.write('%s  %-14s  %s\n' % (formatted_value, oopsids[0], pageid))
+            fp.write('%s  %-14s  %s\n' % (formatted_value,
+                oopsids[0].encode('utf8'), pageid.encode('utf8')))
         fp.write('\n\n')
 
 
