@@ -36,6 +36,7 @@ from oopstools.oops.models import (
     DBOopsRootDirectory,
     Oops,
     parsed_oops_to_model_oops,
+    MAX_URL_LEN
     )
 
 
@@ -253,3 +254,18 @@ class TestParsedToModel(TestCase):
         }
         oops = parsed_oops_to_model_oops(report, 'bug-891647')
         self.assertEqual('APPSERVER', oops.appinstance.title)
+
+    def test_long_url_bug_915335(self):
+        # URLs that are longer than 500 characters should be truncated
+        # at all times.
+        url = 'http://' + '\xFF' * 250
+
+        report = {
+            'id': 'OOPS-68383510f5054932567230492013ce91',
+            'url': url
+        }
+
+        oops = parsed_oops_to_model_oops(report, 'bug-915335')
+        oops.save()
+        self.assertTrue(len(oops.url) < MAX_URL_LEN)
+
